@@ -25,8 +25,8 @@ class Unique(object):
         filters = Filters().add_filter(self.column.name, FilterEqual, self.datamodel, field.data)
         count, obj = self.datamodel.query(filters)
         if (count > 0):
-            # only test if Unique if pk value is diferent, update case.
-            if not (hasattr(form,'_id') and form._id == self.datamodel.get_keys(obj)[0]):
+            # only test if Unique, if pk value is diferent on update.
+            if not hasattr(form,'_id') or form._id != self.datamodel.get_keys(obj)[0]:
                 if self.message is None:
                     self.message = field.gettext(u'Already exists.')
                 raise ValidationError(self.message)
